This crate contains kube-rs compatible bindings for Kubernetes custom resources for the limitador.kuadrant.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
limitador.kuadrant.io/v1alpha1
Limitador